Print barcodes, including qrcode, you can specify the alignment position
and barcode type of the barcode
The unit of height is pixels
No width parameter is required, the width is determined by the specific barcode
Print a horizontal line, you can specify the thickness
of the horizontal line by setting the font size,
or you can directly use the default font without specifying the font size
Print the text content, you can specify the position and font size of the printed text,
and you can print the left, middle, and right text at the same time
Check whether printing is supported.
This method returns true only on goodcom printers.
This method allows the app to distinguish printers from different manufacturers.
Print the image according to the image data.
You can set the alignment position of the printed image,
and decide whether to automatically feed the paper.
If you want to print the text after printing the logo,
the paper will not be automatically fed.
Start printing. Except for image printing, other printing interfaces,
such as drawText, just draw the printing content in the memory first,
and the printing has not been started yet.
This method is to print out the printing content in the memory.